@@ -5,9 +5,9 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = '0.01'; # 2003-09-22 (since 2002-03-26)
+our $VERSION = '0.02'; # 2003-09-22 (since 2002-03-26)
 our @ISA    = qw(Exporter);
-our @EXPORT = qw(sym2name);
+our @EXPORT = qw(sym2name fetch);
 
 use Exporter;
 use Carp;
@@ -16,7 +16,7 @@ use Encode;
 
 =head1 NAME
 
-Finance::YahooJPN::Sym2Name - converts a stock symbol to the name
+Finance::YahooJPN::Sym2Name - converts a Japanese stock symbol to the name
 
 =head1 SYNOPSIS
 
@@ -25,11 +25,11 @@ Finance::YahooJPN::Sym2Name - converts a stock symbol to the name
   # get the name of company of stock symbol code '6758'
   my $stockname = sym2name('6758');
   
-  print $stockname;
+  print $stockname; # it prints 'SONY Corp.'
 
 =head1 DESCRIPTION
 
-This module converts a stock symbol code to the name of company. Japanese stock markets use 4-digit code number as stock symbol. You can get either English or Japanese name of company.
+This module converts a Japanese stock symbol code to the name of company. Japanese stock markets use 4-digit code number as stock symbol. You can get either English or Japanese name of company.
 
 =head1 FUNCTIONS
 
@@ -39,6 +39,8 @@ This module converts a stock symbol code to the name of company. Japanese stock
 
 This function returns a string of the name of company from C<$symbol> (a stock symbol code of 4-digit number).
 
+In case it were a missing code number, the module returns string '(n/a)';
+
 C<$lang> attribute specifies language mode of the company's name. A C<$lang> value is 'eng' (in English) or 'jpn' (in Japanese). This attribute is omittable and the default value is 'eng'.
 
 Note that string data under 'jpn' C<$lang> mode is encoded with UTF-8 character encoding.
@@ -55,6 +57,11 @@ sub sym2name ($;$) {
 	my $url = "http://profile.yahoo.co.jp/biz/fundamental/$symbol.html";
 	my $html = fetch($url);
 	
+	# in case it were a missing code number
+	if ($html =~ m|<h3>指定された URL は存在しません。</h3>|) {
+		return '(n/a)';
+	}
+	
 	# find and extract the name of company in Japanese
 	$html =~ m/<TD bgColor="#6699cc">\n<FONT size="\+1"><B>(.*?)（.*）<\/B><\/FONT>\n/;
 	my $name_jpn = $1;
@@ -95,6 +102,8 @@ sub full2half ($) {
 1;
 __END__
 
+=back
+
 =head1 AUTHOR
 
 Masanori HATA E<lt>lovewing@geocities.co.jpE<gt> (Saitama, JAPAN)
